UncaughtExceptionListener

Struct UncaughtExceptionListener 

pub struct UncaughtExceptionListener { /* private fields */ }

Methods from Deref<Target = Function>

pub fn apply( &self, context: &JsValue, args: &Array, ) -> Result<<T as JsFunction>::Ret, JsValue>
where <T as JsFunction>::Ret: ErasableGenericOwn<<fn() -> JsValue as JsFunction>::Ret>,

The apply() method calls a function with a given this value, and arguments provided as an array (or an array-like object).

MDN documentation

pub fn call0(&self, context: &JsValue) -> Result<Ret, JsValue>
where Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call1(&self, context: &JsValue, arg1: &Arg1) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call2( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call3( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call4( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call5( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call6( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call7( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Arg7: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call8( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Arg7: ErasableGenericBorrow<JsValue>, Arg8: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn call9( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, arg9: &JsValue, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Arg7: ErasableGenericBorrow<JsValue>, Arg8: ErasableGenericBorrow<JsValue>, Ret: ErasableGenericOwn<JsValue>,

👎Deprecated

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

pub fn bind(&self, context: &JsValue) -> Function<T>
where Function<T>: ErasableGenericOwn<Function<fn() -> JsValue>>,

👎Deprecated: Use Function::bind0 instead.

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

MDN documentation

pub fn bind0(&self, context: &JsValue) -> Function<T>
where Function<T>: ErasableGenericOwn<Function<fn() -> JsValue>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind1( &self, context: &JsValue, arg1: &Arg1, ) -> Function<<F as JsFunction1>::Bind1>
where Arg1: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction1>::Bind1>: ErasableGenericOwn<Function<<fn(JsValue) -> JsValue as JsFunction1>::Bind1>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind2( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, ) -> Function<<F as JsFunction2>::Bind2>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction2>::Bind2>: ErasableGenericOwn<Function<<fn(JsValue, JsValue) -> JsValue as JsFunction2>::Bind2>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind3( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, ) -> Function<<F as JsFunction3>::Bind3>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction3>::Bind3>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue) -> JsValue as JsFunction3>::Bind3>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind4( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, ) -> Function<<F as JsFunction4>::Bind4>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction4>::Bind4>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction4>::Bind4>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind5( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, ) -> Function<<F as JsFunction5>::Bind5>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction5>::Bind5>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction5>::Bind5>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind6( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, ) -> Function<<F as JsFunction6>::Bind6>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction6>::Bind6>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction6>::Bind6>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind7( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, ) -> Function<<F as JsFunction7>::Bind7>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Arg7: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction7>::Bind7>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction7>::Bind7>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind8( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, ) -> Function<<F as JsFunction8>::Bind8>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Arg7: ErasableGenericBorrow<JsValue>, Arg8: ErasableGenericBorrow<JsValue>, Function<<F as JsFunction8>::Bind8>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction8>::Bind8>>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn bind9( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, arg9: &JsValue, ) -> Function<fn() -> Ret>
where Arg1: ErasableGenericBorrow<JsValue>, Arg2: ErasableGenericBorrow<JsValue>, Arg3: ErasableGenericBorrow<JsValue>, Arg4: ErasableGenericBorrow<JsValue>, Arg5: ErasableGenericBorrow<JsValue>, Arg6: ErasableGenericBorrow<JsValue>, Arg7: ErasableGenericBorrow<JsValue>, Arg8: ErasableGenericBorrow<JsValue>, Function<fn() -> Ret>: ErasableGenericOwn<Function<fn() -> JsValue>>,

👎Deprecated

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

pub fn length(&self) -> u32

The length property indicates the number of arguments expected by the function.

MDN documentation

pub fn name(&self) -> JsString

A Function object’s read-only name property indicates the function’s name as specified when it was created or “anonymous” for functions created anonymously.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the source code of the function.

MDN documentation

pub fn len(&self) -> usize

Get the static arity of this function type.

pub fn is_empty(&self) -> bool

Returns true if this is a zero-argument function.

pub fn call<Args>( &self, context: &JsValue, args: Args, ) -> Result<<T as JsFunction>::Ret, JsValue>
where Args: JsArgs<T>,

The call() method calls a function with a given this value and arguments provided as a tuple.

This method accepts a tuple of references matching the function’s argument types.

Example
// 0-arg function
let f: Function<fn() -> Number> = get_fn();
let result = f.call(&JsValue::NULL, ())?;

// 1-arg function (note trailing comma for 1-tuple)
let f: Function<fn(JsString) -> Number> = get_fn();
let result = f.call(&JsValue::NULL, (&name,))?;

// 2-arg function
let f: Function<fn(JsString, Boolean) -> Number> = get_fn();
let result = f.call(&JsValue::NULL, (&name, &flag))?;

MDN documentation

pub fn bindn<Args>( &self, context: &JsValue, args: Args, ) -> <Args as JsArgs<T>>::BindOutput
where Args: JsArgs<T>,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

This method accepts a tuple of references to bind.

Example
let f: Function<fn(JsString, Boolean) -> Number> = get_fn();

// Bind no args - same signature
let bound: Function<fn(JsString, Boolean) -> Number> = f.bind(&ctx, ());

// Bind one arg (use 1-tuple of references)
let bound: Function<fn(Boolean) -> Number> = f.bind(&ctx, (&my_string,));

// Bind two args - becomes 0-arg function
let bound: Function<fn() -> Number> = f.bind(&ctx, (&my_string, &my_bool));

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated: Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn as_f64(&self) -> Option<f64>

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returns None.

pub fn is_string(&self) -> bool

Tests whether this JS value is a JS string.

pub fn as_string(&self) -> Option<String>

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider the JsString::try_from() function from js-sys instead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see the documentation about the str type which contains a few caveats about the encodings.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returns None.

pub fn is_null(&self) -> bool

Tests whether this JS value is null

pub fn is_undefined(&self) -> bool

Tests whether this JS value is undefined

pub fn is_null_or_undefined(&self) -> bool

Tests whether this JS value is null or undefined

pub fn is_symbol(&self) -> bool

Tests whether the type of this JS value is symbol

pub fn is_object(&self) -> bool

Tests whether typeof self == "object" && self !== null.

pub fn is_array(&self) -> bool

Tests whether this JS value is an instance of Array.

pub fn is_function(&self) -> bool

Tests whether the type of this JS value is function.

pub fn is_bigint(&self) -> bool

Tests whether the type of this JS value is bigint.

pub fn js_typeof(&self) -> JsValue

Applies the unary typeof JS operator on a JsValue.

MDN documentation

pub fn js_in(&self, obj: &JsValue) -> bool

Applies the binary in JS operator on the two JsValues.

MDN documentation

pub fn is_truthy(&self) -> bool

Tests whether the value is “truthy”.

pub fn is_falsy(&self) -> bool

Tests whether the value is “falsy”.

pub fn loose_eq(&self, other: &JsValue) -> bool

Compare two JsValues for equality, using the == operator in JS.

MDN documentation

pub fn bit_not(&self) -> JsValue

Applies the unary ~ JS operator on a JsValue.

MDN documentation

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Applies the binary >>> JS operator on the two JsValues.

MDN documentation

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

pub fn pow(&self, rhs: &JsValue) -> JsValue

Applies the binary ** JS operator on the two JsValues.

MDN documentation

pub fn lt(&self, other: &JsValue) -> bool

Applies the binary < JS operator on the two JsValues.

MDN documentation

pub fn le(&self, other: &JsValue) -> bool

Applies the binary <= JS operator on the two JsValues.

MDN documentation

pub fn ge(&self, other: &JsValue) -> bool

Applies the binary >= JS operator on the two JsValues.

MDN documentation

pub fn gt(&self, other: &JsValue) -> bool

Applies the binary > JS operator on the two JsValues.

MDN documentation

pub fn unchecked_into_f64(&self) -> f64

Applies the unary + JS operator on a JsValue. Can throw.

MDN documentation